=======
History
=======

0.1.0 (2018-03-05)
------------------

* First release on PyPI. This is just from the cookie cutter template.
* There is no functionality available yet.

0.1.1 (2018-03-06)
------------------
* Add rudimentary functionality
